"use strict";
var command_map_1 = require("../../models/command.map");
var proxy_map_1 = require("../../models/proxy.map");
var broadcast_1 = require("../observer/broadcast");
var notification_1 = require("../observer/notification");
var util_1 = require("../util/util");
var Facade = (function () {
    function Facade() {
    }
    Facade.registerCommand = function (notificationName, commandClassRef) {
        if (!commandClassRef.NAME) {
            commandClassRef.NAME = util_1.Util.createRandomNames('command-');
        }
        var commandMap = this.getCommandMap(commandClassRef);
        if (!commandMap) {
            var commandMap_1 = new command_map_1.CommandMap();
            commandMap_1.name = commandClassRef.NAME;
            commandMap_1.commandClassRef = commandClassRef;
            commandMap_1.listNotificationInterests = [notificationName];
            this.commandMaps.push(commandMap_1);
        }
        else {
            if (commandMap.listNotificationInterests.indexOf(notificationName) < 0) {
                commandMap.listNotificationInterests.push(notificationName);
            }
        }
    };
    Facade.getCommand = function (commandClassRef) {
        var commandMaps = this.getCommandMap(commandClassRef);
        if (commandMaps) {
            return commandMaps.commandClassRef;
        }
        return null;
    };
    Facade.getCommandMap = function (commandClassRef) {
        for (var i = 0; i < this.commandMaps.length; i++) {
            if (this.commandMaps[i].name == commandClassRef.NAME) {
                return this.commandMaps[i];
            }
        }
        return null;
    };
    Facade.registerProxy = function (proxyClassRef, realSubject) {
        if (!proxyClassRef.NAME) {
            proxyClassRef.NAME = util_1.Util.createRandomNames('proxy-');
        }
        if (!this.getProxyMap(proxyClassRef)) {
            var proxyMap = new proxy_map_1.ProxyMap();
            proxyMap.name = proxyClassRef.NAME;
            proxyMap.instance = new proxyClassRef(realSubject);
            this.proxyMaps.push(proxyMap);
        }
    };
    Facade.hasProxy = function (proxyClassRef) {
        if (this.getProxy(proxyClassRef)) {
            return true;
        }
        return false;
    };
    Facade.getProxy = function (proxyClassRef) {
        var proxyMap = this.getProxyMap(proxyClassRef);
        if (proxyMap) {
            return proxyMap.instance;
        }
        return null;
    };
    Facade.getProxyMap = function (proxyClassRef) {
        for (var i = 0; i < this.proxyMaps.length; i++) {
            if (this.proxyMaps[i].name == proxyClassRef.NAME) {
                return this.proxyMaps[i];
            }
        }
        return null;
    };
    Facade.sendNotification = function (notificationName, params, target) {
        var notification = new notification_1.Notification();
        notification.setName(notificationName);
        notification.setBody(params);
        notification.setTarget(target);
        this.commandMaps.forEach(function (commandMap) {
            var listNotificationInterests = commandMap.listNotificationInterests;
            if (listNotificationInterests.indexOf(notificationName) >= 0) {
                var command = new commandMap.commandClassRef();
                command.execute(notification);
            }
        });
        this.broadcast.sendNotification(notificationName, notification);
    };
    Facade.addListener = function (notificationName, listener, mediatorName) {
        this.broadcast.addListener(notificationName, listener, mediatorName);
    };
    Facade.removeListener = function (notificationName, mediatorName) {
        this.broadcast.removeListener(notificationName, mediatorName);
    };
    Facade.removeAllListeners = function (mediatorName) {
        this.broadcast.removeAllListeners(mediatorName);
    };
    Facade.commandMaps = [];
    Facade.proxyMaps = [];
    Facade.broadcast = new broadcast_1.Broadcast();
    return Facade;
}());
exports.Facade = Facade;
