"use strict";
var events = require("events");
var Broadcast = (function () {
    function Broadcast() {
        this.mediators = {};
        this.eventEmitter = new events.EventEmitter();
    }
    Broadcast.prototype.getMediator = function (mediatorName) {
        if (!this.mediators[mediatorName]) {
            this.mediators[mediatorName] = {};
        }
        return this.mediators[mediatorName];
    };
    Broadcast.prototype.addListener = function (notificationName, listener, mediatorName) {
        var mediator = this.getMediator(mediatorName);
        if (mediator[notificationName]) {
            this.removeListener(notificationName, mediatorName);
        }
        mediator[notificationName] = listener;
        this.eventEmitter.on(notificationName, listener);
    };
    Broadcast.prototype.sendNotification = function (notificationName, params) {
        this.eventEmitter.emit(notificationName, params);
    };
    Broadcast.prototype.removeListener = function (notificationName, mediatorName) {
        var mediator = this.getMediator(mediatorName);
        var listener = mediator[notificationName];
        if (listener) {
            this.eventEmitter.removeListener(notificationName, listener);
            delete mediator[notificationName];
        }
    };
    Broadcast.prototype.removeAllListeners = function (mediatorName) {
        var mediator = this.getMediator(mediatorName);
        for (var notificationName in mediator) {
            this.removeListener(notificationName, mediatorName);
        }
        delete this.mediators[mediatorName];
    };
    return Broadcast;
}());
exports.Broadcast = Broadcast;
